const { defineConfig } = require('@vue/cli-service')

const port = process.env.port || process.env.npm_config_port || 80; // 端口

module.exports = defineConfig({
    // 部署生产环境和开发环境下的URL。
    // 默认情况下，Vue CLI 会假设你的应用是被部署在一个域名的根路径上。
    // 例如 https://www.ruoyi.vip/。如果应用被部署在一个子路径上，你就需要用这个选项指定这个子路径。例如，如果你的应用被部署在 https://www.ruoyi.vip/admin/，则设置 baseUrl 为 /admin/。
    publicPath: process.env.NODE_ENV === "production" ? "/gcdist/" : "/",
    // 在npm run build 或 yarn build 时 ，生成文件的目录名称（要和baseUrl的生产环境路径一致）（默认dist）
    outputDir: "dist",
    // 用于放置生成的静态资源 (js、css、img、fonts) 的；（项目打包之后，静态资源会放在这个文件夹下）
    assetsDir: "static",
    // 是否开启eslint保存检测，有效值：ture | false | 'error'
    lintOnSave: process.env.NODE_ENV === "development",
    // 如果你不需要生产环境的 source map，可以将其设置为 false 以加速生产环境构建。
    productionSourceMap: false,
    transpileDependencies: true,
    devServer: {
        host: "0.0.0.0",
        port: port,
        client: {
            overlay: false,
        },
        proxy: {
            '/pdcApi': {
                target: 'https://27.156.118.74:19901', // 你的后端服务器地址
                changeOrigin: true, // 需要虚拟托管站点
                // pathRewrite: {
                //     '^/pdcApi': '' // 移除路径中的/api前缀
                // }
            }
        }
    },
    css: {
        loaderOptions: {
            sass: {
                // additionalData: `@import "@/assets/styles/index.scss";`, // 不同版本的 sass，此属性不同：data、prependData、additionalData
                sassOptions: { outputStyle: 'expanded' } // fix: 解决 element-ui 图标 icon 偶现乱码问题
            }
        }
    },
    chainWebpack: config => {
        config.plugin('define').tap(definitions => {
            Object.assign(definitions[0], {
                __VUE_PROD_HYDRATION_MISMATCH_DETAILS__: 'false'
            });
            return definitions;
        });
    }
})
